@@ -6,3 +6,8 @@ from .gettxoutproofrequest import GetTxOutProofRequest
 from .logrulesrequest import LogRulesRequest
 from .shutdownrequest import ShutdownRequest
 from .validateaddressrequest import ValidateAddressRequest
+
+__all__ = [
+    'DecodeRawTransactionRequest', 'GetBlockHeaderRequest', 'GetRawTransactionRequest', 'GetTxOutRequest', 'GetTxOutProofRequest',
+    'LogRulesRequest', 'ShutdownRequest', 'ValidateAddressRequest'
+]
